==> openGion_core_5.0.2.0.zip: ge/db/oracle/sql/01_TABLE/WKGE52_XINS.sql <==
/**************************************************************************/
/* WKGE52_XIN ( WKGE52_XIN )                                              */
/*                                                                        */
/* Created : 2009/11/04 19:23:38                                          */
/**************************************************************************/
CREATE TABLE WKGE52_XIN (
   GESYSTEM_ID   VARCHAR2(10)                 NOT NULL      /* 10  システムID     */
 , GEYKNO        NUMBER(9)        DEFAULT 0   NOT NULL      /* 20  要求NO         */
 , GESHEETNO     NUMBER(5)        DEFAULT 0   NOT NULL      /* 30  シート番号     */
 , GEEDNO        NUMBER(5)        DEFAULT 0   NOT NULL      /* 40  枝番           */
 , SYSTEM_ID     VARCHAR2(10)                               /* 50  システムID     */
 , LISTID        VARCHAR2(10)                               /* 60  帳票ID         */
 , KBTEXT        VARCHAR2(1)                                /* 70  テキスト区分   */
 , COLUMN_NAME   VARCHAR2(30)                               /* 80  カラム名       */
 , SEQ           NUMBER(5)        DEFAULT 0   NOT NULL      /* 90  順             */
 , START_POS     NUMBER(5)        DEFAULT 0   NOT NULL      /* 100 開始位置       */
 , USE_LENGTH    VARCHAR2(9)      DEFAULT '0' NOT NULL      /* 110 使用桁数       */
 , FGUSE         VARCHAR2(1)                                /* 120 使用フラグ     */
 , RELEASE_NOTES VARCHAR2(120)                              /* 130 リリースノート */
 , RDC_CODE      VARCHAR2(20)                               /* 140 設変番号       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 256K NEXT 16K PCTINCREASE 0 );

==> openGion_core_5.2.0.0.zip: ge/db/oracle/sql/01_TABLE/WKGE52_XINS.sql <==
/**************************************************************************/
/* WKGE52_XIN ( WKGE52_XIN )                                              */
/*                                                                        */
/* Created : 2010/08/05 08:49:42                                          */
/**************************************************************************/
CREATE TABLE WKGE52_XIN (
   GESYSTEM_ID   VARCHAR2(10)                 NOT NULL      /* 10  システムID     */
 , GEYKNO        NUMBER(9)        DEFAULT 0   NOT NULL      /* 20  要求NO         */
 , GESHEETNO     NUMBER(5)        DEFAULT 0   NOT NULL      /* 30  シート番号     */
 , GEEDNO        NUMBER(5)        DEFAULT 0   NOT NULL      /* 40  枝番           */
 , SYSTEM_ID     VARCHAR2(10)                               /* 50  システムID     */
 , LISTID        VARCHAR2(10)                               /* 60  帳票ID         */
 , KBTEXT        VARCHAR2(1)                                /* 70  テキスト区分   */
 , CLM           VARCHAR2(30)                               /* 80  項目           */
 , SEQ           NUMBER(7)        DEFAULT 0   NOT NULL      /* 90  順             */
 , START_POS     NUMBER(5)        DEFAULT 0   NOT NULL      /* 100 開始位置       */
 , USE_LENGTH    VARCHAR2(9)      DEFAULT '0' NOT NULL      /* 110 使用桁数       */
 , FGUSE         VARCHAR2(1)                                /* 120 使用フラグ     */
 , RELEASE_NOTES VARCHAR2(120)                              /* 130 リリースノート */
 , RDC_CODE      VARCHAR2(20)                               /* 140 設変番号       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 256K NEXT 16K PCTINCREASE 0 );
